Some numeric data (e.g., year) in Japan is written with
``Kansu'' characters (or ``Kansuji'') instead of using Arabic numeral
systems. ``Kansu'' is the traditional Japanese numeral systems
adopting Chinese characters. To make such traditional numerals
manipulatable, kansu2arabic() convert them to safe numeric
forms (i.e., Arabic numerals). The variant of ``Kansu'' characters for
financial is also acceptable in kansu2arabic(), though the
function dose not accept any other characters than ``Kansu''
characters.
kansuExample() merely generates an example of Kansu character
vector in order to illustrate how kansu2arabic() works. This
way is a detour to follow the rule of CRAN that prohibits to write
non-ASCII characters in package source files.